@@ -1,47 +1,43 @@
+#' Two way table
+#'
+#' Creates two way tables of categorical variables. The tables created can be
+#' visualized as barplots and mosaicplots.
+#'
+#' @param data A \code{data.frame} or a \code{tibble}.
+#' @param var1 First categorical variable.
+#' @param var2 Second categorical variable.
+#' @param x An object of class \code{cross_table}.
+#' @param stacked If \code{FALSE}, the columns of height are portrayed
+#' as stacked bars, and if \code{TRUE} the columns are portrayed as juxtaposed bars.
+#' @param proportional If \code{TRUE}, the height of the bars is proportional.
+#' @param ... Further arguments to be passed to or from methods.
+#'
+#' @section Deprecated function:
+#' \code{ds_cross_table()} has been deprecated. Instead use
+#' \code{ds_cross_table()}.
+#'
 #' @importFrom graphics barplot mosaicplot
 #' @importFrom grDevices rainbow
-#' @title Two Way Tables
-#' @description \code{ds_cross_tablecross_table} creates two way tables of categorical
-#' variables. The tables created can be visualized as barplots and mosaicplots.
-#' @param data a \code{data.frame} or a \code{tibble}
-#' @param var1 First categorical variable
-#' @param var2 Second categorical variable
-#' @param x An object of class cross_table
-#' @param stacked a logical value. If FALSE, the columns of height are portrayed
-#' as stacked bars, and if TRUE the columns are portrayed as juxtaposed bars.
-#' @param proportional a logical value. If TRUE, the height of the bars is
-#' proportional
-#' @param ... further arguments to be passed to or from methods.
-#' @return \code{ds_cross_table} returns an object of class \code{"ds_cross_table"}.
-#' An object of class \code{"ds_cross_table"} is a list containing at least the
-#' following components:
 #'
-#' \item{obs}{obs number of observations}
-#' \item{var2_levels}{levels of the second categorical variable}
-#' \item{var1_levels}{levels of the first categorical variable}
-#' \item{varnames}{names of the variables}
-#' \item{twowaytable}{table of the variables}
-#' \item{percent_table}{table of percentages}
-#' \item{row_percent}{table of row percentages}
-#' \item{col_percent}{table of column percentages}
-#' \item{column_totals}{total of columns}
-#' \item{percent_column}{total of columns as a percentage}
-#' @section Deprecated Function:
-#' \code{ds_cross_table()} has been deprecated. Instead use \code{ds_cross_table()}.
 #' @examples
-#' k <- ds_cross_table(mtcarz, cyl, am)
+#' k <- ds_cross_table(mtcarz, cyl, gear)
 #' k
 #'
 #' # bar plots
 #' plot(k)
 #' plot(k, stacked = TRUE)
 #' plot(k, proportional = TRUE)
+#'
+#' # alternate
+#' ds_twoway_table(mtcarz, cyl, gear)
+#'
 #' @export
 #'
 ds_cross_table <- function(data, var1, var2) UseMethod("ds_cross_table")
 
 #' @export
 ds_cross_table.default <- function(data, var1, var2) {
+
   var_1 <- enquo(var1)
   var_2 <- enquo(var2)
 
@@ -60,7 +56,7 @@ ds_cross_table.default <- function(data, var1, var2) {
 
   x <- as.matrix(table(varone, vartwo))
   rownames(x) <- NULL
-  n <- length(varone)
+  n <- sum(x)
   if (is.factor(varone)) {
     row_name <- levels(varone)
   } else {
@@ -173,3 +169,56 @@ plot.ds_cross_table <- function(x, stacked = FALSE, proportional = FALSE, ...) {
   result <- list(plot = p)
   invisible(result)
 }
+
+#' @importFrom dplyr summarise tally ungroup mutate inner_join
+#' @importFrom magrittr %<>%
+#' @rdname ds_cross_table
+#' @export
+#'
+ds_twoway_table <- function(data, var1, var2) {
+
+  var_1 <- enquo(var1)
+  var_2 <- enquo(var2)
+
+  group <-
+    data %>%
+    select(!! var_1, !! var_2) %>%
+    drop_na() %>%
+    group_by(!! var_1, !! var_2) %>%
+    summarise(count = n())
+
+  total <-
+    group %>%
+    pull(count) %>%
+    sum()
+
+  div_by <-
+    data %>%
+    group_by(!! var_2) %>%
+    drop_na() %>%
+    tally() %>%
+    pull(n)
+
+
+  group2 <-
+    data %>%
+    select(!! var_1, !! var_2) %>%
+    drop_na() %>%
+    group_by(!! var_2, !! var_1) %>%
+    summarise(count = n()) %>%
+    mutate(
+      col_percent = count / sum(count)
+    ) %>%
+    ungroup()
+
+  group %<>%
+    mutate(
+      percent     = count / total,
+      row_percent = count / sum(count)
+    ) %>%
+    ungroup()
+
+  result <- inner_join(group, group2)
+  return(result)
+
+}
