@@ -11,6 +11,6 @@ if (getRversion() >= "2.15.1") {
   utils::globalVariables(c(
     ".", "breaks",
     "cumulative", "frequency", "values", "s", "tp", "type", "xvar", "yvar",
-    "data", "varnames", "frequency", "varname", "bins", "n", "value", "y"
+    "data", "varnames", "frequency", "varname", "bins", "n", "value", "y", "count"
   ))
 }
