@@ -1,27 +1,32 @@
-#' @importFrom stats median sd var IQR
-#' @importFrom graphics boxplot
-#' @title Descriptive Statistics By Group
-#' @description \code{ds_group_summary} returns descriptive statistics of a
-#' continuous variable for the different levels of a categorical variable.
-#' \code{boxplot.group_summary} creates boxplots of the continuous variable
-#' for the different levels of the categorical variable.
-#' @param data a \code{data.frame} or a \code{tibble}
-#' @param gvar factor; column in \code{data}
-#' @param cvar continuous; column in \code{data}
-#' @param x an object of the class \code{ds_group_summary}
-#' @param ... further arguments to be passed to or from methods
-#' @return \code{ds_group_summary} returns an object of class \code{"ds_group_summary"}.
+#' Groupwise descriptive statistics
+#'
+#' Descriptive statistics of a continuous variable for the different levels of
+#' a categorical variable. \code{boxplot.group_summary()} creates boxplots of
+#' the continuous variable for the different levels of the categorical variable.
+#'
+#' @param data A \code{data.frame} or a \code{tibble}.
+#' @param gvar Column in \code{data}.
+#' @param cvar Column in \code{data}.
+#' @param x An object of the class \code{ds_group_summary}.
+#' @param ... Further arguments to be passed to or from methods.
+#'
+#' @return \code{ds_group_summary()} returns an object of class \code{"ds_group_summary"}.
 #' An object of class \code{"ds_group_summary"} is a list containing the
 #' following components:
 #'
-#' \item{stats}{a data frame containing descriptive statistics for the different
-#' levels of the factor variable}
-#' \item{plotdata}{data for boxplot method}
-#' \item{xvar}{name of the categorical variable}
-#' \item{yvar}{name of the continuous variable}
-#' @section Deprecated Function:
+#' \item{stats}{A data frame containing descriptive statistics for the different
+#' levels of the factor variable.}
+#' \item{tidy_stats}{A tibble containing descriptive statistics for the different
+#' levels of the factor variable.}
+#' \item{plotdata}{Data for boxplot method.}
+#'
+#' @section Deprecated function:
 #' \code{ds_group_summary()} has been deprecated. Instead
 #' use \code{ds_group_summary()}.
+#'
+#' @importFrom stats median sd var IQR
+#' @importFrom graphics boxplot
+#'
 #' @examples
 #' # ds_group summary
 #' ds_group_summary(mtcarz, cyl, mpg)
@@ -29,7 +34,12 @@
 #' # boxplot
 #' k <- ds_group_summary(mtcarz, cyl, mpg)
 #' plot(k)
-#' @seealso \code{link{ds_summary_stats}}
+#'
+#' # tibble
+#' k$tidy_stats
+#'
+#' @seealso \code{\link{ds_summary_stats}}
+#'
 #' @export
 #'
 ds_group_summary <- function(data, gvar, cvar) UseMethod("ds_group_summary")
@@ -37,6 +47,7 @@ ds_group_summary <- function(data, gvar, cvar) UseMethod("ds_group_summary")
 #' @export
 #'
 ds_group_summary.default <- function(data, gvar, cvar) {
+
   g_var <- enquo(gvar)
   c_var <- enquo(cvar)
 
@@ -76,7 +87,7 @@ ds_group_summary.default <- function(data, gvar, cvar) {
       length(gvar), min(gvar), max(gvar), mean(gvar),
       median(gvar), ds_mode(gvar), sd(gvar), var(gvar),
       ds_skewness(gvar), ds_kurtosis(gvar), stat_uss(gvar),
-      ds_css(gvar), ds_cvar(gvar), std_error(gvar),
+      ds_css(gvar), ds_cvar(gvar), ds_std_error(gvar),
       ds_range(gvar), IQR(gvar)
     )
   })
@@ -96,8 +107,22 @@ ds_group_summary.default <- function(data, gvar, cvar) {
   plot_data <- data.frame(gvar, cvar)
   names(plot_data) <- c(xname, yname)
 
+  tidystats <-
+    data %>%
+    select(!! g_var, !! c_var) %>%
+    drop_na() %>%
+    group_by(!! g_var) %>%
+    summarise(length = length(!! c_var), min = min(!! c_var),
+              max = max(!! c_var), mean  = mean(!! c_var),
+              median= median(!! c_var), mode = ds_mode(!! c_var),
+              sd = sd(!! c_var), variance = var(!! c_var),
+              skewness = ds_skewness(!! c_var), kurtosis = ds_kurtosis(!! c_var),
+              coeff_var = ds_cvar(!! c_var), std_error = ds_std_error(!! c_var),
+              range = ds_range(!! c_var), iqr = IQR(!! c_var))
+
   result <- list(
     stats = out,
+    tidy_stats = tidystats,
     plotdata = plot_data,
     xvar = xname,
     yvar = yname,
