@@ -1,50 +1,23 @@
-#' @importFrom stats quantile
-#' @importFrom rlang enquo !!
-#' @title Descriptive Statistics
-#' @description \code{ds_summary_stats} returns a whole range of descriptive
-#' statistics for continuous data.
-#' @param data a \code{data.frame} or a \code{tibble}
-#' @param variable numeric; column in \code{data}
-#' @return \code{ds_summary_stats} returns an object of class
-#' \code{"ds_summary_stats"}. An object of class \code{"ds_summary_stats"}
-#' is a list containing the following components
+#' @title Descriptive statistics
 #'
-#' \item{obs}{number of observations}
-#' \item{missing}{number of missing observations}
-#' \item{avg}{mean}
-#' \item{tavg}{5 percent trimmed mean}
-#' \item{stdev}{standard deviation}
-#' \item{variance}{variance}
-#' \item{skew}{skewness}
-#' \item{kurtosis}{kurtosis}
-#' \item{uss}{uncorrected sum of squares}
-#' \item{css}{corrected sum of squares}
-#' \item{cvar}{coefficient of variation}
-#' \item{sem}{standard error of mean}
-#' \item{median}{median}
-#' \item{mode}{mode}
-#' \item{range}{range}
-#' \item{min}{minimum value}
-#' \item{iqrange}{inter quartile range}
-#' \item{per99}{99th percentile}
-#' \item{per95}{95th percentile}
-#' \item{per90}{90th percentile}
-#' \item{per75}{75th percentile}
-#' \item{per25}{25th percentile}
-#' \item{per10}{10th percentile}
-#' \item{per5}{5th percentile}
-#' \item{per1}{1st percentile}
-#' \item{lowobs}{five lowest observations}
-#' \item{highobs}{five highest observations}
-#' \item{lowobsi}{index of five lowest observations}
-#' \item{highobsi}{index of five highest observations}
-#' @section Deprecated Function:
+#' @description Range of descriptive statistics for continuous data.
+#'
+#' @param data A \code{data.frame} or \code{tibble}.
+#' @param variable Column in \code{data}.
+#'
+#' @section Deprecated function:
 #' \code{summary_stats()} has been deprecated. Instead use
 #' \code{ds_summary_stats()}.
+#'
 #' @examples
 #' ds_summary_stats(mtcarz, mpg)
+#'
+#' @importFrom stats quantile
+#' @importFrom rlang enquo !!
+#'
 #' @seealso \code{\link[base]{summary}} \code{\link{ds_freq_cont}}
 #' \code{\link{ds_freq_table}} \code{\link{ds_cross_table}}
+#'
 #' @export
 #'
 ds_summary_stats <- function(data, variable) UseMethod("ds_summary_stats")
@@ -52,7 +25,13 @@ ds_summary_stats <- function(data, variable) UseMethod("ds_summary_stats")
 #' @export
 #'
 ds_summary_stats.default <- function(data, variable) {
+
   vary <- enquo(variable)
+
+  odata <-
+    data %>%
+    pull(!! vary)
+
   sdata <-
     data %>%
     pull(!! vary) %>%
@@ -68,8 +47,8 @@ ds_summary_stats.default <- function(data, variable) {
   high_val <- ds_rindex(sdata, high)
 
   result <- list(
-    obs = length(sdata),
-    missing = sum(is.na(sdata)),
+    obs = length(odata),
+    missing = sum(is.na(odata)),
     avg = mean(sdata),
     tavg = mean(sdata, trim = 0.05),
     stdev = sd(sdata),
@@ -79,7 +58,7 @@ ds_summary_stats.default <- function(data, variable) {
     uss = stat_uss(sdata),
     css = ds_css(sdata),
     cvar = ds_cvar(sdata),
-    sem = std_error(sdata),
+    sem = ds_std_error(sdata),
     median = median(sdata),
     mode = ds_mode(sdata),
     range = ds_range(sdata),
